Description Usage Arguments Details Value Examples
ISI ranks
1 |
x |
a list of matrices, with the same column names, typically the output of |
sortbyID |
logical, should the output be sorted by ID (default is |
if there is more than one solution resulting from ISI, average (mean) ranks will be calculated. If there is only one solution, the average rank will be the same as the rank from the (one) ISI ranking
a data.frame with at least three columns: IDs, their average rank and the rankings of all rankings that satisfy ISI's minimum criteria
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.