Description Usage Arguments Details Value Examples
add dominance indices to a data set given a dominance matrix
1 |
mat |
a dominance matrix, most likely from |
respdata |
a |
radagio |
logical, by default |
currently, four metrics are calculated:
David's score (via the EloRating package)
randomized Elo-rating (via the EloChoice package)
I&SI (this package)
ADAGIO (this package)
All metrics are returned twice, on their original scale and z-transformed. In addition, the 'true rank' (referred to in the rank column) is also z-transformed.
This function adds new columns to xdata. For this to work, xdata has to have at least two columns with the name ID and rank.
If radagio = FALSE, the function returns ranks as individuals ranked by their proportion of wins. This is meant as a testing strategy because running the ADAGIO algorithm in turn requires the Java ADAGIO software to be run, which first of all is very slow and also interupts workflow because this produces a pop-up window to appear for each instance. The intended use of this argument is to try out simulations that require the calcrank() function. If the simulation works, then this argument can be set to radagio = TRUE (its default).
a data.frame with metrics added
1 2 3 4 5 6 | ## Not run:
domdata <- datagenfunc(gs = 5, Nintm = 3)
xdata <- createresponse(domdata[[2]], 2, effectsize = 2, error = 0.5)
calcranks(domdata[[1]], xdata)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.